@@ -19,8 +19,8 @@
 #ifndef __bookmarklistview_h
 #define __bookmarklistview_h
 
-#include <QTreeView>
 #include <QSortFilterProxyModel>
+#include <QTreeView>
 
 #include "kbookmarkmodel/view.h"
 
@@ -32,46 +32,50 @@ class BookmarkFolderView : public KBookmarkView
 {
     Q_OBJECT
 public:
-    explicit BookmarkFolderView( BookmarkListView * view, QWidget * parent = nullptr );
+    explicit BookmarkFolderView(BookmarkListView *view, QWidget *parent = nullptr);
     virtual ~BookmarkFolderView();
-    void selectionChanged ( const QItemSelection & selected, const QItemSelection & deselected ) override;
-    KBookmark bookmarkForIndex(const QModelIndex & idx) const override;
+    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
+    KBookmark bookmarkForIndex(const QModelIndex &idx) const override;
 private Q_SLOTS:
     void slotReset();
+
 private:
-    BookmarkListView * mview;
-    BookmarkFolderViewFilterModel * mmodel;
+    BookmarkListView *mview;
+    BookmarkFolderViewFilterModel *mmodel;
 };
 
 class BookmarkListView : public KBookmarkView
 {
     Q_OBJECT
 public:
-    explicit BookmarkListView( QWidget * parent = nullptr );
+    explicit BookmarkListView(QWidget *parent = nullptr);
     virtual ~BookmarkListView();
     void loadColumnSetting();
     void saveColumnSetting();
-    void setModel(QAbstractItemModel * model) override;
-    KBookmark bookmarkForIndex(const QModelIndex & idx) const override;
-    KBookmarkModel * bookmarkModel() const;
-protected:
-    void contextMenuEvent ( QContextMenuEvent * e ) override;
-};
+    void setModel(QAbstractItemModel *model) override;
+    KBookmark bookmarkForIndex(const QModelIndex &idx) const override;
+    KBookmarkModel *bookmarkModel() const;
 
+protected:
+    void contextMenuEvent(QContextMenuEvent *e) override;
+};
 
 class BookmarkFolderViewFilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    explicit BookmarkFolderViewFilterModel(QObject * parent = nullptr);
+    explicit BookmarkFolderViewFilterModel(QObject *parent = nullptr);
     virtual ~BookmarkFolderViewFilterModel();
     QStringList mimeTypes() const override;
     bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
+
 protected:
-    bool filterAcceptsColumn ( int source_column, const QModelIndex & source_parent ) const override;
-    bool filterAcceptsRow ( int source_row, const QModelIndex & source_parent ) const override;
-    //FIXME check
+    bool filterAcceptsColumn(int source_column, const QModelIndex &source_parent) const override;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    // FIXME check
     Qt::DropActions supportedDropActions() const override
-        { return sourceModel()->supportedDropActions(); }
+    {
+        return sourceModel()->supportedDropActions();
+    }
 };
 #endif
